#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 Unixutils
version:              1.54.3
visibility:           public
id:                   Unixutils-1.54.3-CqJyFwM4Z8Z27ghyUV5xH3
key:                  Unixutils-1.54.3-CqJyFwM4Z8Z27ghyUV5xH3
license:              BSD-3-Clause
maintainer:           David Fox <ddssff@gmail.com>
author:               Jeremy Shaw, David Fox
homepage:             https://github.com/seereason/haskell-unixutils.git
synopsis:
    A crude interface between Haskell and Unix-like operating systems

description:
    A collection of useful and mildly useful functions that you might
    expect to find in System.* which a heavy bias towards Unix-type operating systems.

category:             System
abi:                  d97d5f0da770fef4fbe49cde771de3c4
exposed:              True
exposed-modules:
    System.Unix.Chroot System.Unix.Crypt System.Unix.Directory
    System.Unix.FilePath System.Unix.Files System.Unix.KillByCwd
    System.Unix.Misc System.Unix.Mount System.Unix.SpecialDevice

import-dirs:          /usr/lib/ghc-9.6.6/site-local/Unixutils-1.54.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/Unixutils-1.54.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/Unixutils-1.54.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unixutils
hs-libraries:         HSUnixutils-1.54.3-CqJyFwM4Z8Z27ghyUV5xH3
extra-libraries:      crypt
depends:
    base-4.18.2.1 bytestring-0.11.5.3 directory-1.3.8.5
    exceptions-0.10.7 filepath-1.4.300.1 mtl-2.3.1 process-1.6.19.0
    process-extras-0.7.4-1tN0mbS8eQp4iPCg4QLmuy
    pureMD5-2.1.4-Jo1qVdZMEIjJtW87EOHzYT
    regex-tdfa-1.3.2.5-GDcLEW3RNnhJam1iRhMaaH unix-2.8.4.0
    zlib-0.7.1.0-o5ZrO8tsYqEMdOctKNx4t

haddock-interfaces:   /usr/share/doc/haskell-unixutils/html/Unixutils.haddock
haddock-html:         /usr/share/doc/haskell-unixutils/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

